@@ -54,8 +54,8 @@
 
 #define GDM_DBUS_NAME "org.gnome.DisplayManager"
 
-static void bus_proxy_destroyed_cb (DBusGProxy *bus_proxy,
-                                    GdmManager *manager);
+static void bus_proxy_destroyed_cb (DBusGProxy  *bus_proxy,
+                                    GdmManager **managerp);
 
 extern char **environ;
 
@@ -189,10 +189,12 @@ bus_reconnect (GdmManager *manager)
         g_signal_connect (bus_proxy,
                           "destroy",
                           G_CALLBACK (bus_proxy_destroyed_cb),
-                          manager);
+                          &manager);
 
         g_debug ("Successfully reconnected to D-Bus");
 
+        gdm_manager_start (manager);
+
         ret = FALSE;
 
  out:
@@ -200,15 +202,20 @@ bus_reconnect (GdmManager *manager)
 }
 
 static void
-bus_proxy_destroyed_cb (DBusGProxy *bus_proxy,
-                        GdmManager  *manager)
+bus_proxy_destroyed_cb (DBusGProxy  *bus_proxy,
+                        GdmManager **managerp)
 {
         g_debug ("Disconnected from D-Bus");
 
-        g_object_unref (manager);
-        manager = NULL;
+        if (managerp == NULL || *managerp == NULL) {
+                /* probably shutting down or something */
+                return;
+        }
 
-        g_timeout_add (3000, (GSourceFunc)bus_reconnect, manager);
+        g_object_unref (*managerp);
+        *managerp = NULL;
+
+        g_timeout_add (3000, (GSourceFunc)bus_reconnect, managerp);
 }
 
 static void
@@ -442,15 +449,6 @@ signal_cb (int      signo,
         ret = TRUE;
 
         switch (signo) {
-        case SIGSEGV:
-        case SIGBUS:
-        case SIGILL:
-        case SIGABRT:
-                g_debug ("Caught signal %d.", signo);
-
-                ret = FALSE;
-                break;
-
         case SIGFPE:
         case SIGPIPE:
                 /* let the fatal signals interrupt us */
@@ -507,25 +505,16 @@ main (int    argc,
         DBusGConnection    *connection;
         GError             *error;
         int                 ret;
-        int                 i;
         gboolean            res;
         gboolean            xdmcp_enabled;
         GdmSignalHandler   *signal_handler;
-        static char        *config_file      = NULL;
         static gboolean     debug            = FALSE;
-        static gboolean     no_daemon        = FALSE;
-        static gboolean     no_console       = FALSE;
         static gboolean     do_timed_exit    = FALSE;
         static gboolean     print_version    = FALSE;
         static gboolean     fatal_warnings   = FALSE;
         static GOptionEntry entries []   = {
-                { "config", 0, 0, G_OPTION_ARG_STRING, &config_file, N_("Alternative GDM System Defaults configuration file"), N_("CONFIGFILE") },
-
                 { "debug", 0, 0, G_OPTION_ARG_NONE, &debug, N_("Enable debugging code"), NULL },
                 { "fatal-warnings", 0, 0, G_OPTION_ARG_NONE, &fatal_warnings, N_("Make all warnings fatal"), NULL },
-                { "no-daemon", 0, 0, G_OPTION_ARG_NONE, &no_daemon, N_("Don't become a daemon"), NULL },
-                { "no-console", 0, 0, G_OPTION_ARG_NONE, &no_console, N_("No console (static) servers to be run"), NULL },
-
                 { "timed-exit", 0, 0, G_OPTION_ARG_NONE, &do_timed_exit, N_("Exit after a time - for debugging"), NULL },
                 { "version", 0, 0, G_OPTION_ARG_NONE, &print_version, N_("Print GDM version"), NULL },
 
@@ -544,15 +533,7 @@ main (int    argc,
 
         context = g_option_context_new (_("GNOME Display Manager"));
         g_option_context_add_main_entries (context, entries, NULL);
-
-        /* preprocess the arguments to support the xdm style -nodaemon
-         * option
-         */
-        for (i = 0; i < argc; i++) {
-                if (strcmp (argv[i], "-nodaemon") == 0) {
-                        argv[i] = (char *) "--no-daemon";
-                }
-        }
+        g_option_context_set_ignore_unknown_options (context, TRUE);
 
         error = NULL;
         res = g_option_context_parse (context, &argc, &argv, &error);
@@ -571,10 +552,6 @@ main (int    argc,
                 g_log_set_always_fatal (fatal_mask);
         }
 
-        if (! no_daemon && daemon (0, 0)) {
-                g_error ("Could not daemonize: %s", g_strerror (errno));
-        }
-
         connection = get_system_bus ();
         if (connection == NULL) {
                 goto out;
@@ -638,20 +615,19 @@ main (int    argc,
         g_signal_connect (bus_proxy,
                           "destroy",
                           G_CALLBACK (bus_proxy_destroyed_cb),
-                          manager);
+                          &manager);
 
         main_loop = g_main_loop_new (NULL, FALSE);
 
         signal_handler = gdm_signal_handler_new ();
-        gdm_signal_handler_set_main_loop (signal_handler, main_loop);
+        gdm_signal_handler_set_fatal_func (signal_handler,
+                                           (GDestroyNotify)g_main_loop_quit,
+                                           main_loop);
+        gdm_signal_handler_add_fatal (signal_handler);
         gdm_signal_handler_add (signal_handler, SIGTERM, signal_cb, NULL);
         gdm_signal_handler_add (signal_handler, SIGINT, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGILL, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGBUS, signal_cb, NULL);
         gdm_signal_handler_add (signal_handler, SIGFPE, signal_cb, NULL);
         gdm_signal_handler_add (signal_handler, SIGHUP, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGSEGV, signal_cb, NULL);
-        gdm_signal_handler_add (signal_handler, SIGABRT, signal_cb, NULL);
         gdm_signal_handler_add (signal_handler, SIGUSR1, signal_cb, NULL);
 
         if (do_timed_exit) {
@@ -662,6 +638,8 @@ main (int    argc,
 
         g_main_loop_run (main_loop);
 
+        g_debug ("GDM finished, cleaning up...");
+
         if (manager != NULL) {
                 g_object_unref (manager);
         }
@@ -674,6 +652,9 @@ main (int    argc,
                 g_object_unref (signal_handler);
         }
 
+        gdm_settings_direct_shutdown ();
+        gdm_log_shutdown ();
+
         g_main_loop_unref (main_loop);
 
         ret = 0;
